@@ -14,14 +14,18 @@ setClass(
 
 
 #' 
-#' RxODE engine class.
+#' RxODE/rxode2 engine class.
 #' 
+#' @slot rxode2 logical field to indicate if CAMPSIS should use rxode2 (field set to TRUE)
+#'  or RxODE (field set to FALSE). Default is TRUE.
 #' @export
 setClass(
   "rxode_engine",
   representation(
+    rxode2="logical"
   ),
-  contains="simulation_engine" 
+  contains="simulation_engine",
+  prototype=prototype(rxode2=TRUE)
 )
 
 #' 
@@ -33,4 +37,4 @@ setClass(
   representation(
   ),
   contains="simulation_engine" 
-)
\ No newline at end of file
+)
